@@ -74,49 +74,92 @@ enum {
 	N_COLUMNS
 };
 
+enum {
+        PROP_0,
+        PROP_BOOK_MANAGER
+};
+
 G_DEFINE_TYPE_WITH_PRIVATE (DhBookTree, dh_book_tree, GTK_TYPE_TREE_VIEW);
 
 static gint signals[LAST_SIGNAL] = { 0 };
 
 static void
-book_tree_finalize (GObject *object)
+dh_book_tree_dispose (GObject *object)
 {
         DhBookTreePrivate *priv = dh_book_tree_get_instance_private (DH_BOOK_TREE (object));
 
         /* Disconnect signals */
-        if (g_signal_handler_is_connected (priv->book_manager, priv->book_created_id))
+        if (priv->book_created_id != 0 &&
+            g_signal_handler_is_connected (priv->book_manager, priv->book_created_id)) {
                 g_signal_handler_disconnect (priv->book_manager, priv->book_created_id);
-        if (g_signal_handler_is_connected (priv->book_manager, priv->book_deleted_id))
+                priv->book_created_id = 0;
+        }
+
+        if (priv->book_deleted_id &&
+            g_signal_handler_is_connected (priv->book_manager, priv->book_deleted_id)) {
                 g_signal_handler_disconnect (priv->book_manager, priv->book_deleted_id);
-        if (g_signal_handler_is_connected (priv->book_manager, priv->book_enabled_id))
+                priv->book_deleted_id = 0;
+        }
+
+        if (priv->book_enabled_id != 0 &&
+            g_signal_handler_is_connected (priv->book_manager, priv->book_enabled_id)) {
                 g_signal_handler_disconnect (priv->book_manager, priv->book_enabled_id);
-        if (g_signal_handler_is_connected (priv->book_manager, priv->book_disabled_id))
+                priv->book_enabled_id = 0;
+        }
+
+        if (priv->book_disabled_id != 0 &&
+            g_signal_handler_is_connected (priv->book_manager, priv->book_disabled_id)) {
                 g_signal_handler_disconnect (priv->book_manager, priv->book_disabled_id);
-        if (g_signal_handler_is_connected (priv->book_manager, priv->group_by_language_id))
+                priv->book_disabled_id = 0;
+        }
+
+        if (priv->group_by_language_id != 0 &&
+            g_signal_handler_is_connected (priv->book_manager, priv->group_by_language_id)) {
                 g_signal_handler_disconnect (priv->book_manager, priv->group_by_language_id);
+                priv->group_by_language_id = 0;
+        }
 
-        g_object_unref (priv->store);
-        g_object_unref (priv->book_manager);
+        g_clear_object (&priv->store);
+        g_clear_object (&priv->book_manager);
 
-        G_OBJECT_CLASS (dh_book_tree_parent_class)->finalize (object);
+        G_OBJECT_CLASS (dh_book_tree_parent_class)->dispose (object);
 }
 
 static void
-dh_book_tree_class_init (DhBookTreeClass *klass)
+dh_book_tree_get_property (GObject    *object,
+                           guint       prop_id,
+                           GValue     *value,
+                           GParamSpec *pspec)
 {
-        GObjectClass *object_class = G_OBJECT_CLASS (klass);
+        DhBookTreePrivate *priv = dh_book_tree_get_instance_private (DH_BOOK_TREE (object));
 
-	object_class->finalize = book_tree_finalize;
+        switch (prop_id) {
+                case PROP_BOOK_MANAGER:
+                        g_value_set_object (value, priv->book_manager);
+                        break;
+                default:
+                        G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+                        break;
+        }
+}
 
-        signals[LINK_SELECTED] =
-                g_signal_new ("link-selected",
-			      G_TYPE_FROM_CLASS (klass),
-			      G_SIGNAL_RUN_LAST,
-			      0,
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__POINTER,
-			      G_TYPE_NONE,
-			      1, G_TYPE_POINTER);
+static void
+dh_book_tree_set_property (GObject      *object,
+                           guint         prop_id,
+                           const GValue *value,
+                           GParamSpec   *pspec)
+{
+        DhBookTreePrivate *priv = dh_book_tree_get_instance_private (DH_BOOK_TREE (object));
+
+        switch (prop_id) {
+                case PROP_BOOK_MANAGER:
+                        g_return_if_fail (priv->book_manager == NULL);
+                        priv->book_manager = g_value_dup_object (value);
+                        break;
+                default:
+                        G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+                        break;
+        }
 }
 
 static void
@@ -677,16 +720,11 @@ book_tree_init_selection (DhBookTree *tree)
 					   tree);
 }
 
-GtkWidget *
-dh_book_tree_new (DhBookManager *book_manager)
+static void
+dh_book_tree_constructed (GObject *object)
 {
-        DhBookTree       *tree;
-        DhBookTreePrivate   *priv;
-
-	tree = g_object_new (DH_TYPE_BOOK_TREE, NULL);
-        priv = dh_book_tree_get_instance_private (tree);
-
-        priv->book_manager = g_object_ref (book_manager);
+        DhBookTree *tree = DH_BOOK_TREE (object);
+        DhBookTreePrivate *priv = dh_book_tree_get_instance_private (tree);
 
         priv->book_created_id = g_signal_connect (priv->book_manager,
                                                   "book-created",
@@ -713,7 +751,43 @@ dh_book_tree_new (DhBookManager *book_manager)
 
         book_tree_init_selection (tree);
 
-        return GTK_WIDGET (tree);
+        G_OBJECT_CLASS (dh_book_tree_parent_class)->constructed (object);
+}
+
+static void
+dh_book_tree_class_init (DhBookTreeClass *klass)
+{
+        GObjectClass *object_class = G_OBJECT_CLASS (klass);
+
+        object_class->dispose = dh_book_tree_dispose;
+        object_class->get_property = dh_book_tree_get_property;
+        object_class->set_property = dh_book_tree_set_property;
+        object_class->constructed = dh_book_tree_constructed;
+
+        g_object_class_install_property (object_class,
+                                         PROP_BOOK_MANAGER,
+                                         g_param_spec_object ("book-manager",
+                                                              "Book Manager",
+                                                              "The book maanger",
+                                                              DH_TYPE_BOOK_MANAGER,
+                                                              G_PARAM_READWRITE |
+                                                              G_PARAM_CONSTRUCT_ONLY));
+
+        signals[LINK_SELECTED] =
+                g_signal_new ("link-selected",
+			      G_TYPE_FROM_CLASS (klass),
+			      G_SIGNAL_RUN_LAST,
+			      0,
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__POINTER,
+			      G_TYPE_NONE,
+			      1, G_TYPE_POINTER);
+}
+
+GtkWidget *
+dh_book_tree_new (DhBookManager *book_manager)
+{
+        return GTK_WIDGET (g_object_new (DH_TYPE_BOOK_TREE, "book-manager", book_manager, NULL));
 }
 
 static gboolean
